Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2077)

Unified Diff: pkg/unittest/core_matchers.dart

Issue 10909166: Rename NoSuchMethodException to NoSuchMethodError. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address review comments Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/html/templates/html/impl/impl_Element.darttemplate ('k') | pkg/unittest/test/matchers_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/unittest/core_matchers.dart
diff --git a/pkg/unittest/core_matchers.dart b/pkg/unittest/core_matchers.dart
index 3da9b019546b453ab46869d26a9631133a61d084..3e76a5bffc4d0395de5a6bfa72e53fce7918626b 100644
--- a/pkg/unittest/core_matchers.dart
+++ b/pkg/unittest/core_matchers.dart
@@ -459,16 +459,16 @@ class _IndexOutOfRangeException extends _ExceptionMatcher {
bool matches(item, MatchState matchState) => item is IndexOutOfRangeException;
}
-/** A matcher for NoSuchMethodExceptions. */
-const isNoSuchMethodException = const _NoSuchMethodException();
+/** A matcher for NoSuchMethodErrors. */
+const isNoSuchMethodError = const _NoSuchMethodError();
-/** A matcher for functions that throw NoSuchMethodException */
-const Matcher throwsNoSuchMethodException =
- const _Throws(isNoSuchMethodException);
+/** A matcher for functions that throw NoSuchMethodError */
+const Matcher throwsNoSuchMethodError =
+ const _Throws(isNoSuchMethodError);
-class _NoSuchMethodException extends _ExceptionMatcher {
- const _NoSuchMethodException() : super("NoSuchMethodException");
- bool matches(item, MatchState matchState) => item is NoSuchMethodException;
+class _NoSuchMethodError extends _ExceptionMatcher {
+ const _NoSuchMethodError() : super("NoSuchMethodError");
+ bool matches(item, MatchState matchState) => item is NoSuchMethodError;
}
/** A matcher for NotImplementedExceptions. */
« no previous file with comments | « lib/html/templates/html/impl/impl_Element.darttemplate ('k') | pkg/unittest/test/matchers_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698